<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>À l&apos;instant</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 nouveau message</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>Il y a %1 minutes</translation>
    </message>
</context>
</TS>